@@ -3,9 +3,9 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20211029';
+our $VERSION = '0.20211130';
 
-# Table last modified: 2021-10-29
+# Table last modified: 2021-11-30
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[02]1|55|77|88)|612))',
     '002' => '(?:850[1-4])',
@@ -103,15 +103,15 @@ our %ZIP_TABLE = (
     '097' => '(?:8(?:5(?:10|85|5[58]|2[57])|6(?:[03]9|[68]6)))',
     '098' => '(?:(?:5(?:[78]92|298|595)|(?:28|62|0[13])92|1(?:69[23]|792)|339[23568]))',
     '099' => '(?:(?:2(?:19[2-8]|49[235]|392)|1(?:49[2568]|19[78]|595)|3(?:29[23]|69[78])|4(?:19[256]|492)|(?:56|65)92|049[245]))',
-    '100' => '(?:(?:8(?:9(?:4[015]|3[0-37]|8[0-3679]|9[46]|2[0-24679]|1[02-9]|0[1-579]|5[0-35689]|7[013-9]|6[0-257-9])|1(?:1[0137-9]|0[1-589]|7[12468]|8[124-9]|2[013-8]|4[014]|5[0-248]|6[05689]|3[0-69])|2(?:28|51|70|0[1357]|8[2358]|3[2-5]|1[4-69]|4[156]|6[0258])|3(?:70|5[015]|2[1245]|3[1-38]|0[2367]|4[15]|1[01]|8[038])|5(?:11|33|4[03]|5[058]|2[02]|6[07]|8[58]|7[57]|0[235-7])|6(?:55|2[019]|6[356]|7[67]|1[07]|0[126]|3[129]|4[049])|4(?:02|5[06]|1[015]|2[0147]|3[09]|[48][48])|0(?:19|8[06]|5[015]|7[07-9]|6[56])|79[1-4])|6(?:1(?:62|7[0-57]|5[0-2])|2(?:55|77|6[02])|0(?:51|66|80)|75[1-6])|149[28]))',
-    '101' => '(?:8(?:5(?:7[5-9]|6[0-2568]|8[0135689]|1[0257-9]|4[2-58]|0[1246-9]|5[24589]|2[0-8]|3[0-5])|4(?:7[05-7]|8[013]|0[57-9]|3[0379]|2[1-579]|5[0-4689]|4[13-9]|6[0-24-9]|1[0-35689])|3(?:6[2356]|4[5-7]|0[12578]|7[0-258]|8[1358]|5[0-689]|2[13-8]|3[013568]|1[013-7])|6(?:8[28]|6[2578]|1[0-25-79]|3[01346-8]|5[14-6]|4[1-3568]|2[014-9]|7[026]|0[3-79])|9(?:01|50|7[0-37]|4[16]|8[36])|0(?:11|77|5[04]|0[128])|2(?:28|0[124]|1[0359])|7(?:0[137]|1[0-25-8])|1(?:01|89)))',
+    '100' => '(?:(?:8(?:9(?:4[015]|3[0-37]|8[0-3679]|9[46]|2[0-24679]|1[02-9]|0[1-579]|5[0-35689]|7[013-9]|6[0-257-9])|1(?:1[0137-9]|5[0-2458]|0[1-589]|7[12468]|8[124-9]|2[013-8]|4[014]|6[05689]|3[0-69])|2(?:28|51|70|0[1357]|8[2358]|3[2-5]|1[4-69]|4[156]|6[0258])|3(?:70|5[015]|2[1245]|3[1-38]|0[2367]|4[15]|1[01]|8[038])|5(?:11|33|4[03]|5[058]|2[02]|6[07]|8[58]|7[57]|0[235-7])|6(?:55|2[019]|6[356]|7[67]|1[07]|0[126]|3[129]|4[049])|4(?:02|5[06]|1[015]|3[09]|2[147]|[48][48])|0(?:19|8[06]|5[015]|7[07-9]|6[56])|79[1-4])|6(?:1(?:62|7[0-57]|5[0-2])|2(?:55|77|6[02])|0(?:51|66|80)|75[1-6])|149[28]))',
+    '101' => '(?:8(?:5(?:7[5-9]|6[0-2568]|8[0135689]|1[0257-9]|4[2-58]|0[1246-9]|5[24589]|2[0-8]|3[0-5])|4(?:7[05-7]|8[013]|0[57-9]|3[0379]|2[1-579]|5[0-4689]|4[13-9]|6[0-24-9]|1[0-35689])|3(?:6[2356]|4[5-7]|0[12578]|7[0-258]|8[1358]|5[0-689]|2[13-8]|3[013568]|1[013-7])|6(?:4[1-35-8]|8[28]|6[2578]|1[0-25-79]|3[01346-8]|5[14-6]|2[014-9]|7[026]|0[3-79])|9(?:01|50|7[0-37]|4[16]|8[36])|0(?:11|77|5[04]|0[128])|2(?:28|0[124]|1[0359])|7(?:0[137]|1[0-25-8])|1(?:01|89)))',
     '102' => '(?:8(?:1(?:2[02-58]|8[124-8]|5[0-25]|3[0-289]|0[1-39]|7[0-25-8]|9[0-5]|4[0-24]|6[016]|1[0-257-9])|5(?:0[2-468]|1[0-2569]|8[04-68]|4[013]|5[2-9]|7[01378]|3[0-39]|2[02589]|6[013-79])|6(?:3[0-3579]|4[2-5]|2[0-26-8]|8[0589]|7[17-9]|1[0-47-9]|5[0156]|6[06-8]|0[1-4679])|4(?:7[047]|6[0-24-68]|5[0-259]|0[124-7]|4[0158]|2[0146]|8[489]|3[037]|1[01479])|2(?:5[015]|7[2357]|3[0-24-68]|6[045]|8[28]|2[1-68]|[01][15]|4[016])|3(?:0[2359]|4[19]|3[1-36]|2[124]|1[0134]|8[1-38]|6[24]|7[0237]|5[0367])|0(?:30|2[24-6]|7[78]|8[0-358]|5[05]|0[58]|1[125689])|7(?:30|9[58])))',
-    '103' => '(?:(?:8(?:4(?:7[0-3]|2[2-7]|0[1-57]|6[0-24-68]|4[38]|8[02478]|3[0-589]|1[0-79]|5[016])|2(?:5[0-2569]|3\d|6[01356]|0[1-68]|8[2457]|1[0-248]|2[124589]|7[03568]|4[013578])|3(?:7[03]|1[1378]|5[0-2458]|2[1348]|0[136-8]|8[0348]|4[15-7]|6[036]|3[01357-9])|5(?:1[0-257]|5[12468]|7[17]|0[1-36]|2[0-25]|6[67]|8[4-68]|3[4-8]|4[238])|6(?:40|5[0136]|7[067]|6[068]|8[0469]|3[1269])|0[01]1)|6060))',
-    '104' => '(?:(?:8(?:1(?:2[2-589]|0[124-689]|6[12578]|1[014-8]|8[1389]|4[25]|3[0-589]|5[18]|7[014-9])|3(?:7[027-9]|1[0-3579]|2[458]|8[013689]|6[05]|5[0167]|0[1-7]|3[02358]|4[0-5])|5(?:72|1[028]|3[035689]|8[01458]|4[3-8]|5[014-689]|2[0136-8]|6[06-8]|0[1256])|4(?:70|3[013589]|5[056]|1[035689]|0[124-8]|8[168]|4[02-489]|2[0-469]|6[08])|2(?:40|71|1[0-258]|3[38]|0[568]|8[0-589]|5[0-24-8]|6[026])|6(?:14|5[06]|6[0158]|8[05]|7[08])|0(?:55|77|0[1-47]|1[01]))|6241))',
-    '105' => '(?:(?:8(?:4(?:8[2-6]|5[1-36-8]|6[014-689]|7[0-357]|3[1-7]|0[1-3578]|4[014-9]|2[0347-9]|1[0-24-9])|5(?:6[03578]|5[013-8]|1[0-25-8]|8[0-589]|7[4-9]|0[1-3578]|2[1-57-9]|3[0457]|4[03-6])|6(?:3[04]|6[0568]|8[015689]|2[01356]|5[468]|1[013-57]|4[024]|7[06-8]|0[3468])|3(?:3[01358]|0[1-8]|2[0235]|1[0-589])|0(?:[12]0|39|55|0[1258]|7[07]|8[58])|7(?:88|0[127]|1[1267]))|7(?:0(?:50|77)|444)|6[09]50))',
+    '103' => '(?:(?:8(?:4(?:7[0-3]|2[2-7]|0[1-57]|6[0-24-68]|4[38]|8[02478]|3[0-589]|1[0-79]|5[016])|2(?:5[0-2569]|3\d|7[0368]|6[01356]|0[1-68]|8[2457]|1[0-248]|2[124589]|4[013578])|3(?:7[03]|1[1378]|5[0-2458]|2[1348]|0[136-8]|8[0348]|4[15-7]|6[036]|3[01357-9])|5(?:1[0-257]|5[12468]|7[17]|0[1-36]|2[0-25]|6[67]|8[4-68]|3[4-8]|4[238])|6(?:40|5[0136]|7[067]|6[068]|8[0469]|3[1269])|0[01]1)|6060))',
+    '104' => '(?:(?:8(?:1(?:2[2-589]|0[124-689]|6[12578]|1[014-8]|8[1389]|4[25]|3[0-589]|5[18]|7[014-9])|3(?:65|1[0-3579]|7[07-9]|2[458]|8[013689]|5[0167]|0[1-7]|3[02358]|4[0-5])|5(?:72|1[028]|3[035689]|8[01458]|4[3-8]|5[014-689]|2[0136-8]|6[06-8]|0[1256])|4(?:70|3[013589]|5[056]|1[035689]|0[124-8]|8[168]|4[02-489]|2[0-469]|6[08])|2(?:40|71|6[26]|1[0-258]|3[38]|0[568]|8[0-589]|5[0-24-8])|6(?:14|5[06]|6[0158]|8[05]|7[08])|0(?:55|77|0[1-47]|1[01]))|6241))',
+    '105' => '(?:(?:8(?:4(?:8[2-6]|5[1-36-8]|6[014-689]|7[0-357]|3[1-7]|0[1-3578]|4[014-9]|2[0347-9]|1[0-24-9])|5(?:6[03578]|5[013-8]|1[0-25-8]|8[0-57-9]|7[4-9]|0[1-3578]|2[1-57-9]|3[0457]|4[03-6])|6(?:3[04]|6[0568]|8[015689]|2[01356]|5[468]|1[013-57]|4[024]|7[06-8]|0[3468])|3(?:3[01358]|0[1-8]|2[0235]|1[0-589])|0(?:[12]0|39|55|0[1258]|7[07]|8[58])|7(?:88|0[127]|1[1267]))|7(?:0(?:50|77)|444)|6[09]50))',
     '106' => '(?:(?:8(?:5(?:6[0-35-79]|0[78]|7[136-8]|3[17]|1[458]|2[12]|5[0-25689]|4[145]|8[0157-9])|6(?:77|4[0-2489]|5[25]|1[168]|6[58]|0[18]|2[0256]|3[069])|0(?:11|39|0[17])|(?:10|79)7|4(?:01|87))|6(?:1(?:61|88)|06[06])))',
     '107' => '(?:8(?:4(?:20|34|5[06]|0[1-4]|7[17]|8[24]|6[036-8]|1[0-246-9]|4[08])|5(?:32|81|1[14]|0[2578]|7[27]|2[0178]|6[037]|5[0268]|4[56])|6(?:50|8[06]|0[14]|1[5-79]|7[46]|3[0-3689]|2[0357]|6[68])|3(?:55|60|4[0289]|7[013]|2[0346]|8[048]|3[026])|0(?:[16]0|77|0[16])|797))',
-    '108' => '(?:(?:8(?:5(?:2[0-35]|4[03-58]|3[02369]|0[1-36-9]|6[0468]|7[0135]|5[0-35-8]|1[0-2]|8[0-3568])|3(?:2[25689]|8[013-689]|3[0348]|5[058]|6[01]|4[15]|7[23589]|1[035]|0[13578])|2(?:8[028]|2[0-245]|7[056]|4[0-38]|1[0-25-7]|0[1-36-9]|3[0-4]|5[05])|4(?:56|85|0[3-57]|2[013-5]|7[078]|1[014-7]|3[29]|6[68]|4[48])|6(?:50|0[1267]|1[0-25-7]|2[28]|3[1-3689]|4[0-28])|0(?:[258]0|[17]1|0[15])|7(?:07|1[03])|11[78])|63(?:50|63)))',
+    '108' => '(?:(?:8(?:5(?:2[0-35]|4[03-58]|3[02369]|0[1-36-9]|6[0468]|7[0135]|5[0-35-8]|1[0-2]|8[0-3568])|3(?:2[25689]|7[2359]|8[013-689]|3[0348]|5[058]|6[01]|4[15]|1[035]|0[13578])|2(?:8[028]|2[0-245]|7[056]|4[0-38]|1[0-25-7]|0[1-36-9]|3[0-4]|5[05])|4(?:56|85|0[3-57]|2[013-5]|7[078]|1[014-7]|3[29]|6[68]|4[48])|6(?:50|0[1267]|1[0-25-7]|2[28]|3[1-3689]|4[0-28])|0(?:[258]0|[17]1|0[15])|7(?:07|1[03])|11[78])|63(?:50|63)))',
     '109' => '(?:8792)',
     '110' => '(?:8(?:5(?:6[0-25-7]|4[01368]|5[0589]|7[5-8]|3[0-4679]|0[1-3579]|1[0135-7]|8[02-468]|2[024])|6(?:53|2[0-2568]|6[0259]|4[1245]|3[0158]|0[259]|8[015-7]|1[04589]|7[35-8])|7(?:8[027]|1[2-6]|2[235]|3[36]|0[68])|408|807))',
     '111' => '(?:8(?:5(?:43|1[0-258]|8[058]|5[1568]|7[57]|6[0167]|2[125]|0[125-8]|3[0-59])|6(?:4[028]|3[01379]|[12][0-258]|7[6-8]|8[1368]|0[2568]|6[16]|5[05])|7(?:[56]5|21|98|0[178]|1[01])|081))',
@@ -202,7 +202,7 @@ our %ZIP_TABLE = (
     '214' => '(?:85(?:[26]5|33|8[058]|7[01]))',
     '215' => '(?:85(?:09|30|42|66|7[06]|1[015]|8[58]|5[08]|2[017]))',
     '216' => '(?:8(?:5(?:[56]6|01|22|70|1[0-249])|631))',
-    '220' => '(?:8(?:5(?:77|1[015]|6[05-7]|3[0689]|2[0-3]|5[89]|8[0568]|0[12]|4[0-2])|6(?:53|78|0[149]|1[1-6]|6[08]|8[046]|2[035])|7(?:11|22|39|65|5[05])|080|173|401))',
+    '220' => '(?:8(?:5(?:77|1[015]|6[05-7]|3[0689]|2[0-3]|5[89]|8[0568]|0[12]|4[0-2])|6(?:53|78|0[149]|1[1-6]|6[08]|8[046]|2[035])|7(?:11|39|65|2[02]|5[05])|080|173|401))',
     '221' => '(?:8(?:5(?:[46]0|37|88|2[0239]|5[08]|1[017])|7(?:41|65|1[28]|0[1-35])|6(?:[68]6|11|23)))',
     '222' => '(?:8(?:5(?:3[03]|8[056]|6[1-6]|7[57]|0[157-9]|1[15]|5[0268]|2[035])|6[25]2))',
     '223' => '(?:85(?:[58][058]|1[0-25]|2[0-35-7]|7[27]|6[067]|4[0-2]|0[125-8]|3[039]))',
@@ -339,7 +339,7 @@ our %ZIP_TABLE = (
     '363' => '(?:8(?:5(?:10|0[159]|5[58])|601))',
     '364' => '(?:8(?:5(?:[01]1|[58]5)|633))',
     '365' => '(?:8(?:5(?:85|1[24]|0[1-3568])|60[13]))',
-    '366' => '(?:85(?:67|81|1[015]|0[12]))',
+    '366' => '(?:85(?:[28]1|67|1[015]|0[12]))',
     '367' => '(?:(?:0(?:29[26-8]|19[248])|8(?:501|686)))',
     '368' => '(?:(?:8(?:6(?:66|8[06])|50[125])|0(?:19[235]|292)))',
     '369' => '(?:(?:1(?:29[2358]|89[2-5]|19[235]|59[236]|[34]92|998)|0(?:29[2357]|19[258]|39[235])))',
@@ -421,7 +421,7 @@ our %ZIP_TABLE = (
     '447' => '(?:8(?:5(?:0[1-35-7]|1[0-2])|6(?:[18]0|0[1358])))',
     '448' => '(?:8(?:6(?:10|22|0[1259]|5[0-35-7]|6[0156]|8[68]|7[017])|5(?:11|50|0[156]|2[35]|3[13-5]|4[023])|731))',
     '449' => '(?:029[23])',
-    '450' => '(?:(?:8(?:5(?:40|85|0[135]|[23][03]|6[17]|7[57]|1[15])|6(?:[05]1|[48]0|2[06]|1[1458])|7(?:11|30|65)|99[35-7])|6(?:(?:13|36)3|660)))',
+    '450' => '(?:(?:8(?:5(?:40|85|0[135]|[23][03]|6[17]|7[57]|1[15])|6(?:[05]1|[48]0|2[06]|1[1458])|7(?:11|65)|99[35-7])|6(?:(?:13|36)3|660)))',
     '451' => '(?:8(?:5(?:[14]1|2[02]|[56][0158]|0[1-38]|7[0157])|6(?:[15]0|66|88)|701))',
     '452' => '(?:8(?:5(?:70|0[1-3]|6[1-79])|60[12]))',
     '453' => '(?:8(?:5(?:40|8[015]|3[39]|7[07]|5[58]|6[57]|2[12]|0[15]|1[0-28])|7(?:58|65|77|0[124])|6(?:[01]1|62|86)))',
@@ -623,7 +623,7 @@ our %ZIP_TABLE = (
     '657' => '(?:85(?:01|70))',
     '658' => '(?:85(?:01|70|5[58]))',
     '659' => '(?:85(?:11|0[1-3]))',
-    '660' => '(?:85(?:01|33|67|4[04]|[58][058]|1[01]))',
+    '660' => '(?:85(?:01|33|67|4[04]|5[058]|1[01]|8[0258]))',
     '661' => '(?:8(?:5(?:[23]0|01|77|6[47]|5[058]|8[58]|1[01])|661))',
     '662' => '(?:85(?:[34]3|10|21|67|8[056]|5[258]|0[1-35]))',
     '663' => '(?:8(?:5(?:[67]7|01|10|45|58|8[568])|601))',
@@ -636,8 +636,8 @@ our %ZIP_TABLE = (
     '670' => '(?:8(?:5(?:43|3[03]|2[04]|7[057]|8[058]|0[1-356]|6[67]|5[0458]|1[017])|6(?:5[25]|6[068]|7[57]|8[029])))',
     '671' => '(?:(?:1(?:2(?:9[235]|8[0-35689])|6(?:92|8[0-248])|1(?:92|8[018])|59[235]|39[23])|2(?:19[238]|59[358]|28[08])|419[23]|0295))',
     '672' => '(?:8(?:5(?:01|67|5[058]|8[58])|6(?:55|66|77)))',
-    '673' => '(?:(?:8(?:5(?:[01]1|85)|6[68]6)|1(?:49[3-5]|192|395)|0[45]92))',
-    '674' => '(?:8(?:5(?:[58]5|01)|686))',
+    '673' => '(?:(?:8(?:5(?:[01]1|85)|6(?:66|8[68]))|1(?:49[3-5]|192|395)|0[45]92))',
+    '674' => '(?:8(?:5(?:01|85)|686))',
     '675' => '(?:(?:8(?:5(?:22|33|66|77|88|1[019]|5[58]|0[15])|6(?:11|8[68]))|01(?:9[2-468]|8[0-68])|1(?:3(?:80|9[25])|192|297)|239[35]))',
     '676' => '(?:8(?:5(?:01|33|40|58|66|85|1[03])|6(?:55|7[07]|8[68])))',
     '677' => '(?:851[01])',
